import { __decorate } from "tslib";
import { Connect, Session } from '@genesislcap/foundation-comms';
import { attr, observable } from '@microsoft/fast-element';
import { FoundationElement } from '@microsoft/fast-foundation';
import { combineLatest } from 'rxjs';
import { foundationConnectionIndicatorStyles as styles } from './connection-indicator.styles';
import { foundationConnectionIndicatorTemplate as template } from './connection-indicator.template';
export class ConnectionIndicator extends FoundationElement {
    constructor() {
        super(...arguments);
        this.showLabel = false;
        this.label = 'disconnected';
        this.colour = 'red';
    }
    connectedCallback() {
        super.connectedCallback();
        this.subscription = combineLatest([this.connect._status, this.connect._hostUrl]).subscribe((update) => {
            this.label = this.getLabel(...update);
            this.colour = this.getColour(update[0]);
        });
    }
    disconnectedCallback() {
        var _a;
        (_a = this.subscription) === null || _a === void 0 ? void 0 : _a.unsubscribe();
    }
    getLabel(status, hostUrl) {
        if (status === 'connected') {
            return `${hostUrl} ✔`;
        }
        return status;
    }
    getColour(status) {
        switch (status) {
            case 'connected':
                return 'green';
            case 'disconnected':
                return 'red';
            case 'busy':
                return 'orange';
        }
    }
}
__decorate([
    Connect
], ConnectionIndicator.prototype, "connect", void 0);
__decorate([
    Session
], ConnectionIndicator.prototype, "session", void 0);
__decorate([
    attr({ mode: 'boolean', attribute: 'show-label' })
], ConnectionIndicator.prototype, "showLabel", void 0);
__decorate([
    observable
], ConnectionIndicator.prototype, "label", void 0);
__decorate([
    observable
], ConnectionIndicator.prototype, "colour", void 0);
export const foundationConnectionIndicator = ConnectionIndicator.compose({
    baseName: 'connection-indicator',
    template,
    styles,
});
